# This file is executed on every boot (including wake-boot from deepsleep)

import sys

# Set default path
# Needed for importing modules and upip

sys.path.insert(0,'/flash/lib')
#sys.path[1] = '/flash/lib'


#wifi setup and service
import sys,uos,m5stack,os,network,machine,time
def read_ssid_data(file="ssid_password.txt"):
    login_data={}
    network_data={}
    network_type=""
    try:
        for line in open(file, 'r'):
            if "[" in line:
                network_data={}
                network_type=line[1:-2]
            else:
                temp=line.strip().split("=")
                network_data[temp[0]]=temp[1].split(",")
            login_data[network_type]=network_data
        return login_data
    except:
        return None

def seache_ssid(ssid,ssid_dict):
    ssid_list=ssid_dict.values()
    for ssid_password in ssid_list:
        if ssid in ssid_password["ssid"]:
            return ssid_password
    return None

def wlan_scan_list_byte_to_str(scan_byte_list):
    scan_str_list=[]
    for access_point in scan_byte_list:
        scan_str_list.append([access_point[0].decode(),access_point[3]])
    scan_str_list=sorted(scan_str_list, key=lambda x: x[1],reverse=True)
    return scan_str_list

def seache_ssid_from_ssid_password_dict(access_point_list,ssid_dict):
    for access_point in access_point_list:
        result=seache_ssid(access_point[0],ssid_dict)
        if result!=None:
            return result
    return None

def network_service_start():
    #network service start
    network.telnet.start(user='micro', password='python', timeout=300)
    network.ftp.start(user='micro', password='python', buffsize=1024, timeout=300)
    print("telnet & ftp server started!")
    m5stack.lcd.println("telnet & ftp server started!")
    print("user=micro password=python")
    m5stack.lcd.println("user=micro password=python")
    return

def sd_card_main_start():
    #access point wierkess ap setup
    wlan_ap        = network.WLAN(1)
    wlan_ap.active(True)
    

    #mount sd card
    print("sd card mounting...")
    m5stack.lcd.println("sd card mounting...")
    try:
        uos.sdconfig(uos.SDMODE_SPI, clk=18, mosi=23, miso=19, cs=4) 
        uos.mountsd()
        #change pwd
        sys.path.insert(0,"/sd/lib")
        os.chdir("/sd")
    except:
        print("sdcard can't mount")
        m5stack.lcd.println("sdcard can't mount")
        
    print("current directory is "+os.getcwd())
    m5stack.lcd.println("current directory is "+os.getcwd())    
    
    #wierless network client
    client_flag=("ssid_password.txt" in os.listdir())
    if client_flag:
        print("find ssid_password.txt!")
        m5stack.lcd.println("find ssid_password.txt!")
        #setup wifi
        wlan_client    = network.WLAN(0)
        wlan_client.active(True)
        #scan wifi
        print("scanning access point...")
        m5stack.lcd.println("scanning access point...")
        #byte to str and signal sort
        access_point_list=wlan_client.scan()
        access_point_list=wlan_scan_list_byte_to_str(access_point_list)
        #load ssid password
        ssid_password_dict=read_ssid_data("ssid_password.txt")
        if ssid_password_dict!=None:
            connect_data=seache_ssid_from_ssid_password_dict(access_point_list,ssid_password_dict)
        else:
            connect_data=None
        if connect_data!=None:
        #connect wifi
            m5stack.lcd.println("connecting to "+connect_data["ssid"][0] + "  ...")
            wlan_client.connect(connect_data["ssid"][0],connect_data["password"][0])
            time.sleep(5)
            #print ip addr
            client_ip_adr=wlan_client.ifconfig()[0]
            m5stack.lcd.println("client_ip="+client_ip_adr)
            #rtc sync
            rtc = machine.RTC()
            rtc.init((2019, 1, 1, 12, 12, 12))
            rtc.ntp_sync(server= 'ntp.nict.jp', tz='JST-9', update_period=300)
        else:
            print("can't found ssid")
            m5stack.lcd.println("can't found ssid")
    else:
        print("can't found ssid_password.txt!")
        m5stack.lcd.println("can't found ssid_password.txt!")
    #access point ip print
    ap_ip_adr=wlan_ap.ifconfig()[0]
    m5stack.lcd.println("acsesspoint_ip="+ap_ip_adr)
    network_service_start()

    
sd_card_main_start()

