
import sys,os
from mpu9250 import MPU9250
from ak8963 import AK8963
import m5stack
from machine import I2C, Pin
import time
import gc


#calibration
def calibration():
    print("TODO")
    """
    m5stack.lcd.println("start calibration push A button")
    while m5stack.buttonA.isPressed()==False:
        pass
    m5stack.lcd.println("accel calibration stop A button")
    time.sleep(2)
    imu.accel.calibrate(m5stack.buttonA.isPressed)
    imu.accel.cal=imu.accel.cal[0],imu.accel.cal[1],1-imu.accel.cal[2]
    time.sleep(2)
    m5stack.lcd.println("gyro calibration stop A button")
    imu.gyro.calibrate(m5stack.buttonA.isPressed)
    time.sleep(2)
    m5stack.lcd.println("magnetic calibration stop A button")
    imu.mag.calibrate(m5stack.buttonA.isPressed)
    """

    return



def monitor(sensor):
    m5stack.lcd.clear()
    m5stack.lcd.setCursor(0, 0)
    m5stack.lcd.setColor(m5stack.lcd.WHITE)
    fw, fh = m5stack.lcd.fontSize()
    m5stack.lcd.print('Acceleration', 0, 0)
    m5stack.lcd.print('Gyro', 0, fh * 4)
    m5stack.lcd.print('Magnetic', 0, fh * 8)
    try:
        while True:
            ax, ay, az = sensor.acceleration
            gx, gy, gz = sensor.gyro
            mx, my, mz = sensor.magnetic
            print("accel    ",ax, ay, az)
            print("gyro     ",gx, gy, gz)
            print("mag      ",mx, my, mz)
            m5stack.lcd.print(' ax: {:+.5f}'.format(ax), 0, fh * 1)
            m5stack.lcd.print(' ay: {:+.5f}'.format(ay), 0, fh * 2)
            m5stack.lcd.print(' az: {:+.5f}'.format(az), 0, fh * 3)
            
            m5stack.lcd.print(' gx: {:+.5f}'.format(gx), 0, fh * 5)
            m5stack.lcd.print(' gy: {:+.5f}'.format(gy), 0, fh * 6)
            m5stack.lcd.print(' gz: {:+.5f}'.format(gz), 0, fh * 7)
            
            m5stack.lcd.print(' mx: {:+.5f}'.format(mx), 0, fh * 9)
            m5stack.lcd.print(' my: {:+.5f}'.format(my), 0, fh * 10)
            m5stack.lcd.print(' mz: {:+.5f}'.format(mz), 0, fh * 11)
            time.sleep(0.1)
    except KeyboardInterrupt:
        return

def save_data(sensor,file_name):
    f = open(file_name, "w")
    gc.collect()
    start_time=time.time()
    try:
        for count in range(999999999):
            ax, ay, az ,gx, gy, gz,mx, my, mz= sensor.acceleration + sensor.gyro+sensor.magnetic
            f.write(",".join(map(str,[count,time.time()-start_time,ax, ay, az,gx, gy, gz,mx, my, mz,"\n"])))
    except KeyboardInterrupt:
        f.close()
        gc.collect()
    return 

def write_offset_data(file_name,list_data,mode="w"):
    f = open(file_name, mode)
    for line in list_data:
        f.write(str(line)[1:-1]+'\n')
    f.close()
    return
def read_offset_data(file_name):
    f = open(file_name, "r")
    result=[]
    for line in f:
        temp=[]
        for value in line.strip().split(","):
            temp.append(float(value))
        result.append(tuple(temp))
    f.close()
    return result

def main():
    #setup i2c
    i2c=I2C(freq=200000,scl=Pin(22), sda=Pin(21))
    sensor = MPU9250(i2c)
    ak8963 = AK8963(
        i2c,
        offset=(-308.390625, 494.50078125, 34.5703125),
        scale=(1.13960619887368, 1.03423165308741, 0.865349439710335)
    )
    sensor=MPU9250(i2c, ak8963=ak8963)
    while True:
        try:
            command=input("command=")
        except KeyboardInterrupt:
            command="end"

        if command=="end":
            i2c.deinit()
            print("restart command [import main]")
            print("see you...")
            sys.exit()
        elif command=="help":
            gc.collect()
            print("command list")
            print(["monitor","save data","save cal","load cal","help","end"])
        elif command=="monitor":
            gc.collect()
            print("Ctrl-C stop...")
            time.sleep(1)
            try:
                monitor(sensor)
            except KeyboardInterrupt:
                pass
            m5stack.lcd.clear()
            m5stack.lcd.setCursor(0, 0)
            m5stack.lcd.setColor(m5stack.lcd.WHITE)
            print("stop monitor")

        elif command=="save cal":
            """
            gc.collect()
            calibration()
            write_offset_data("imu_offset.dat",[imu.accel.cal,imu.gyro.cal,imu.mag.cal])
            print("accel offset=",imu.accel.cal)
            print("gyro offset=",imu.gyro.cal)
            print("mag offset=",imu.mag.cal)
            """
        elif command=="load cal":
            """
            gc.collect()
            #calibration()
            imu.accel.cal,imu.gyro.cal,imu.mag.cal=read_offset_data("imu_offset.dat")
            print("accel offset=",imu.accel.cal)
            print("gyro offset=",imu.gyro.cal)
            print("mag offset=",imu.mag.cal)
            """
        elif command=="save data":
            gc.collect()
            file_name=input("save file name= ")
            while len(file_name)==0:
                file_name=input("save file name= ")
            print("Ctrl-C stop and save ... ")
            input("start to enter please ...")
            print("start!")
            try:
                save_data(sensor,file_name)
            except KeyboardInterrupt:
                pass
            print("stop saving")
        else:
            print("command not found")


main()



